==> index_now_commerce-1.0.0.tar.gz: index_now_commerce/src/CommerceProductOperations.php <==
<?php

namespace Drupal\index_now_commerce;

use Drupal\commerce_product\Entity\Product;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\user\RoleInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Commerce product operations.
 */
class CommerceProductOperations implements ContainerInjectionInterface, CommerceProductOperationsInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The index now service.
   *
   * @var \Drupal\index_now\Service\IndexNowInterface
   */
  protected $indexNow;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorage
   */
  protected $roleStorage;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\index_now\Service\IndexNowInterface $index_now
   *   The index now service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    IndexNowInterface $index_now
  ) {
    $this->configFactory = $config_factory;
    $this->roleStorage = $entity_type_manager->getStorage('user_role');
    $this->indexNow = $index_now;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('index_now.indexnow')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function pingIndexNow(Product $commerce_product) {
    if ($this->isIndexable($commerce_product)) {
      $route_parameters = [
        'commerce_product' => $commerce_product->id(),
      ];
      $options = [
        'absolute' => TRUE,
        'language' => $commerce_product->language(),
      ];
      $product_url = Url::fromRoute('entity.commerce_product.canonical', $route_parameters, $options);
      $this->indexNow->sendRequest($product_url->toString());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isIndexable(Product $commerce_product) {
    if (!$commerce_product->isPublished()) {
      return FALSE;
    }

    /** @var \Drupal\user\Entity\Role $anonymous_role */
    $anonymous_role = $this->roleStorage->load(RoleInterface::ANONYMOUS_ID);
    if (!$anonymous_role->hasPermission('access content')) {
      return FALSE;
    }

    $exclude_product_types = $this->configFactory
      ->getEditable('index_now.settings')
      ->get('exclude_commerce_product_types');
    $exclude_product_types = !is_array($exclude_product_types) ? [] : array_filter(array_values($exclude_product_types));

    return !in_array($commerce_product->bundle(), $exclude_product_types);
  }

}

==> index_now_commerce-1.1.0.tar.gz: index_now_commerce/src/CommerceProductOperations.php <==
<?php

namespace Drupal\index_now_commerce;

use Drupal\commerce_product\Entity\Product;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\user\RoleInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Commerce product operations.
 */
class CommerceProductOperations implements ContainerInjectionInterface, CommerceProductOperationsInterface {

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorage
   */
  protected $roleStorage;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entitTypeManager
   *   The entity type manager.
   * @param \Drupal\index_now\Service\IndexNowInterface $indexNow
   *   The index now service.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected EntityTypeManagerInterface $entitTypeManager,
    protected IndexNowInterface $indexNow
  ) {
    $this->roleStorage = $entitTypeManager->getStorage('user_role');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('index_now.indexnow')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function pingIndexNow(Product $commerce_product) {
    if ($this->isIndexable($commerce_product)) {
      $route_parameters = [
        'commerce_product' => $commerce_product->id(),
      ];
      $options = [
        'absolute' => TRUE,
        'language' => $commerce_product->language(),
      ];
      $product_url = Url::fromRoute('entity.commerce_product.canonical', $route_parameters, $options);
      $this->indexNow->sendRequest($product_url->toString());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isIndexable(Product $commerce_product) {
    if (!$commerce_product->isPublished()) {
      return FALSE;
    }

    /** @var \Drupal\user\Entity\Role $anonymous_role */
    $anonymous_role = $this->roleStorage->load(RoleInterface::ANONYMOUS_ID);
    if (!$anonymous_role->hasPermission('access content')) {
      return FALSE;
    }

    $exclude_product_types = $this->configFactory
      ->getEditable('index_now.settings')
      ->get('exclude_commerce_product_types');
    $exclude_product_types = !is_array($exclude_product_types) ? [] : array_filter(array_values($exclude_product_types));

    return !in_array($commerce_product->bundle(), $exclude_product_types);
  }

}
